"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createMockMiddleware = void 0;
const fs_1 = __importDefault(require("fs"));
const router_1 = __importDefault(require("./router"));
const operations_1 = require("./operations");
const middleware_1 = require("./middleware");
const createMockMiddleware = ({ spec, options = {}, configure, }) => {
    if (typeof spec === 'string' && !fs_1.default.existsSync(spec)) {
        throw new Error(`OpenAPI spec not found at location: ${spec}`);
    }
    else if (spec === undefined) {
        throw new Error(`OpenAPI spec not provided`);
    }
    const router = (0, router_1.default)();
    const operations = (0, operations_1.createOperations)({ spec, options, callback: configure });
    router.use('/{0,}', (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
        res.locals.operation = yield operations.match(req);
        res.locals.operations = Object.assign(Object.assign({}, (res.locals.operations ? res.locals.operations : {})), { [spec.toString()]: operations });
        next();
    }));
    router.use(middleware_1.isAuthenticated, middleware_1.validateHeaders, middleware_1.validatePath, middleware_1.validateQuery, middleware_1.validateBody);
    router.use((req, res, next) => {
        return res.locals.operation ? res.locals.operation.generateResponse(req, res) : next();
    });
    return router;
};
exports.createMockMiddleware = createMockMiddleware;
//# sourceMappingURL=index.js.map